==> download.php?FileName=terralib-5.2.4-ubuntu-14.04.tar.gz: uninstall.sh <==
#!/bin/bash
#
#  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#
#  Description: Performs TerraLib uninstallation on Linux Ubuntu.
#  Author: TerraLib Team <terralib-team@terralib.org>
#
#  Example:
#  $ ./uninstall.sh
#

echo "***********************************************"
echo "* TerraLib Uninstaller for Linux Ubuntu 14.04 *"
echo "***********************************************"
echo ""
sleep 1s

#
# Valid parameter val or abort script
#
function valid_operation()
{
  if [ $1 -ne 0 ]; then
    echo ""
    echo $2
    echo ""
    exit $1
  fi
}

#
# Uninstall dpkg debian packages
#

#
# TerraLib Layout version 1.2.0 
#
terralib_layout_test=`dpkg -s terralib-layout | grep Status`

if [ "$terralib_layout_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-layout
  valid_operation $? "Error: could not uninstall terralib layout!" 
  echo "terralib layout uninstalled!"
else
  echo "terralib layout already uninstalled!"
fi

#
# TerraLib version 5.2.4 
#
terralib_test=`dpkg -s terralib-5.2.4 | grep Status`

if [ "$terralib_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-5.2.4
  valid_operation $? "Error: could not uninstall terralib!" 
  echo "terralib uninstalled!"
else
  echo "terralib already uninstalled!"
fi

#
# Boost version 1.60.0
#
boost_test=`dpkg -s terralib-boost | grep Status`

if [ "$boost_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-boost
  valid_operation $? "Error: could not uninstall boost!" 
  echo "boost uninstalled!"
else
  echo "boost already uninstalled!"
fi

#
# GDAL/OGR version 2.1.3
#
gdal_test=`dpkg -s terralib-gdal | grep Status`

if [ "$gdal_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-gdal
  valid_operation $? "Error: could not uninstall gdal!" 
  echo "gdal uninstalled!"
else
  echo "gdal already uninstalled!"
fi

#
# Qt Property Browser version 2.6.1
#
qtpb_test=`dpkg -s terralib-qtpb | grep Status`

if [ "$qtpb_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-qtpb
  valid_operation $? "Error: could not uninstall qtpropertybrowser!" 
  echo "qtpropertybrowser uninstalled!"
else
  echo "qtpropertybrowser already uninstalled!"
fi

#
# Qwt version 6.1.2
#
qwt_test=`dpkg -s terralib-qwt| grep Status`

if [ "$qwt_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-qwt
  valid_operation $? "Error: could not uninstall qwt!" 
  echo "qwt uninstalled!"
else
  echo "qwt already uninstalled!"
fi

#
# Wtss Cxx version 0.4.0
#
wtss_test=`dpkg -s terralib-wtss-cxx| grep Status`

if [ "$wtss_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-wtss-cxx
  valid_operation $? "Error: could not uninstall wtss-cxx!" 
  echo "wtss-cxx uninstalled!"
else
  echo "wtss-cxx already uninstalled!"
fi

#
# Automatically removes unused libraries 
#
sudo apt-get autoremove -y

#
# Remove TerraLib files
#
sudo rm -rf $HOME/.config/INPE/TerraView-5.2.4.ini $HOME/.local/share/INPE/TerraView-5.2.4

echo ""
echo "**************************"
echo "* Finished Successfully! *"
echo "**************************"
echo ""

==> download.php?FileName=terralib-5.3.0-ubuntu-14.04.tar.gz: uninstall.sh <==
#!/bin/bash
#
#  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#
#  Description: Performs TerraLib uninstallation on Linux Ubuntu.
#  Author: TerraLib Team <terralib-team@terralib.org>
#
#  Example:
#  $ ./uninstall.sh
#

echo "***********************************************"
echo "* TerraLib Uninstaller for Linux Ubuntu 14.04 *"
echo "***********************************************"
echo ""
sleep 1s

#
# Valid parameter val or abort script
#
function valid_operation()
{
  if [ $1 -ne 0 ]; then
    echo ""
    echo $2
    echo ""
    exit $1
  fi
}

#
# Uninstall dpkg debian packages
#

#
# TerraLib Layout version 1.2.0 
#
terralib_layout_test=`dpkg -s terralib-layout | grep Status`

if [ "$terralib_layout_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-layout
  valid_operation $? "Error: could not uninstall terralib layout!" 
  echo "terralib layout uninstalled!"
else
  echo "terralib layout already uninstalled!"
fi

#
# TerraLib version 5.3.0 
#
terralib_test=`dpkg -s terralib-5.3.0 | grep Status`

if [ "$terralib_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-5.3.0
  valid_operation $? "Error: could not uninstall terralib!" 
  echo "terralib uninstalled!"
else
  echo "terralib already uninstalled!"
fi

#
# Boost version 1.60.0
#
boost_test=`dpkg -s terralib-boost | grep Status`

if [ "$boost_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-boost
  valid_operation $? "Error: could not uninstall boost!" 
  echo "boost uninstalled!"
else
  echo "boost already uninstalled!"
fi

#
# GDAL/OGR version 2.1.3
#
gdal_test=`dpkg -s terralib-gdal | grep Status`

if [ "$gdal_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-gdal
  valid_operation $? "Error: could not uninstall gdal!" 
  echo "gdal uninstalled!"
else
  echo "gdal already uninstalled!"
fi

#
# Qt Property Browser version 2.6.1
#
qtpb_test=`dpkg -s terralib-qtpb | grep Status`

if [ "$qtpb_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-qtpb
  valid_operation $? "Error: could not uninstall qtpropertybrowser!" 
  echo "qtpropertybrowser uninstalled!"
else
  echo "qtpropertybrowser already uninstalled!"
fi

#
# Qwt version 6.1.2
#
qwt_test=`dpkg -s terralib-qwt| grep Status`

if [ "$qwt_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-qwt
  valid_operation $? "Error: could not uninstall qwt!" 
  echo "qwt uninstalled!"
else
  echo "qwt already uninstalled!"
fi

#
# Wtss Cxx version 0.4.0
#
wtss_test=`dpkg -s terralib-wtss-cxx| grep Status`

if [ "$wtss_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-wtss-cxx
  valid_operation $? "Error: could not uninstall wtss-cxx!" 
  echo "wtss-cxx uninstalled!"
else
  echo "wtss-cxx already uninstalled!"
fi

#
# Qscintilla version 2.10.0 
#
terralib_qsci_test=`dpkg -s terralib-qscintilla | grep Status`

if [ "$terralib_qsci_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-qscintilla
  valid_operation $? "Error: could not uninstall terralib qscintilla!" 
  echo "terralib qscintilla uninstalled!"
else
  echo "terralib qscintilla already uninstalled!"
fi

#
# QtLua version 2.10.0 
#
terralib_qtlua_test=`dpkg -s terralib-qtlua | grep Status`

if [ "$terralib_qtlua_test" == "Status: install ok installed" ]; then
  sudo dpkg -r terralib-qtlua
  valid_operation $? "Error: could not uninstall terralib qtlua!" 
  echo "terralib qtlua uninstalled!"
else
  echo "terralib qtlua already uninstalled!"
fi

#
# Automatically removes unused libraries 
#
sudo apt-get autoremove -y

#
# Remove TerraLib files
#
sudo rm -rf $HOME/.config/INPE/TerraView-5.3.0.ini $HOME/.local/share/INPE/TerraView-5.3.0

echo ""
echo "**************************"
echo "* Finished Successfully! *"
echo "**************************"
echo ""
